@@ -6,9 +6,13 @@
    Copyright (C) 2002 Free Software Foundation Inc.
    Contributed by Andreas Bauer <baueran@in.tum.de>  */
 
-/* { dg-do run { target i?86-*-* x86_64-*-*} } */
+/* { dg-do run { target i?86-*-* s390*-*-* x86_64-*-*} } */
+/* { dg-skip-if "" { { i?86-*-* x86_64-*-* } && ilp32 } { "-fpic" "-fPIC" } { "" } } */
 /* { dg-options "-O2 -foptimize-sibling-calls" } */
 
+extern void abort (void);
+extern void exit (int);
+
 int foo (int);
 int bar (int);
 
